## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)

## ----echo=FALSE, out.width = '25%'--------------------------------------------
knitr::include_graphics("hex-hce.png")

## ----setup--------------------------------------------------------------------
library(hce)
packageVersion("hce")

## -----------------------------------------------------------------------------
args("propWINS")
propWINS(WO = 1.5, WR = 2)

## -----------------------------------------------------------------------------
propWINS(WO = 1.25, WR = 1.5, Overall = 120*150)

